==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NotificationHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * NotificationHub properties.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property name Gets or sets the NotificationHub name.
 * @property registrationTtl Gets or sets the RegistrationTtl of the created NotificationHub
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class NotificationHubPropertiesArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val name: Output<String>? = null,
    public val registrationTtl: Output<String>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .registrationTtl(registrationTtl?.applyValue({ args0 -> args0 }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [NotificationHubPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationHubPropertiesArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var name: Output<String>? = null

    private var registrationTtl: Output<String>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("dtktnnqophywlfww")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("lkrydxxkjqsiqtau")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("piapvqlqhrgjgyat")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("nbljmkomophittiv")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("mpbpjqppjbrdaaqq")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("xkuxawhffoijursq")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("lwqrrcgvnocflmbj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("vlnfgbsfyljtedpo")
    public suspend fun registrationTtl(`value`: Output<String>) {
        this.registrationTtl = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("vcxldtvadaamridf")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("hxkuggchiycmlvxw")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("mqodwmkyjmmoxylj")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("clbogwvnrjbwtfqe")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("vowmrpfhpsvawjiw")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("aynvnutqxiwxcqxl")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("xgnybbliqivoblfd")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("opxbncqkiegkties")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("xygonbjlidggfuyr")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("kjvjufnyyuvpdjdd")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("mysqqyfrtucjxatb")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("vijcaofoxmmialiv")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("dilskxmetiuooxfi")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("cvttfwjnnhnlpgai")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("yxvrbgrujnlomist")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("uhuigsiotekfyjyi")
    public suspend fun registrationTtl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTtl = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("pewrytsmcturrgbd")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("vrdtsqgysibwctkn")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("xnvjevngfjaxdywn")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("aaqvfdotxufncpmq")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): NotificationHubPropertiesArgs = NotificationHubPropertiesArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        name = name,
        registrationTtl = registrationTtl,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NotificationHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * NotificationHub properties.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property name Gets or sets the NotificationHub name.
 * @property registrationTtl Gets or sets the RegistrationTtl of the created NotificationHub
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class NotificationHubPropertiesArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val name: Output<String>? = null,
    public val registrationTtl: Output<String>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .registrationTtl(registrationTtl?.applyValue({ args0 -> args0 }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [NotificationHubPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationHubPropertiesArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var name: Output<String>? = null

    private var registrationTtl: Output<String>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("ccmlagtyvcerwpyh")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("umyusvjgovxqqhpu")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("ruxectnstjrbshjg")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("vtgfnchbvfiaadey")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("wdikiduaujqjngdr")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("hthbqptnuolcubhv")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("wugufjjxjjqoicdo")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("taxbrgrgjqjbqwnc")
    public suspend fun registrationTtl(`value`: Output<String>) {
        this.registrationTtl = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("xcpaornpftqvguft")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("tmocajmonlkfjdol")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("ldbovvuowpvsuldj")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("ynovnpvltteitixv")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("mmsuxmjyllfcwdud")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("vpvgwdwqdmkvbrjn")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("ghjuomqrxnsvleub")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("kqbyosrbgqojebnr")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("rnntdiaxvbopuojj")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("uxgxhgektuvyobdn")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("ytpewyosjjpffoaw")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("vxwtpewaoolrtkjj")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("peencsheorlwlsva")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("pyyhrrnihrrnkbog")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("qrjvtslhvspblgxn")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("oonunhwsbipsbuiu")
    public suspend fun registrationTtl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTtl = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("bewxudnncesdqnoe")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("ihgswsoacsgvomhg")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("arvusnypdrdrtjht")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("ibmrunnpbmqsyjic")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): NotificationHubPropertiesArgs = NotificationHubPropertiesArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        name = name,
        registrationTtl = registrationTtl,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}
